@@ -7,6 +7,8 @@ foo$bar@baz
 foo$bar()
 foo$"bar"
 foo$bar()$baz[[1]]$bam
+foo$...
+foo$..1
 
 # ------------------------------------------------------------------------------
 # dollar no rhs
@@ -20,6 +22,8 @@ foo@bar
 foo@bar$baz
 foo@bar()
 foo@"bar"
+foo@...
+foo@..1
 
 # ------------------------------------------------------------------------------
 # slot no rhs
