@@ -51,7 +51,6 @@ NA_complex_
 12332L
 0L
 12L
-0xDEADL
 
 # ------------------------------------------------------------------------------
 # floats
@@ -60,9 +59,43 @@ NA_complex_
 .11
 123.4123
 .1234
-0xDEAD
 x <- -.66
 
+# ------------------------------------------------------------------------------
+# hexadecimal
+
+# `x` vs `X`
+0x123
+0X123
+
+# Numbers and letters
+0xDEAD
+0XDEAD
+0x1f2F3
+0X1f2F3
+
+# `p` vs `P`
+0x0p0
+0x0P0
+0x0p123
+0x0P123
+
+# `+` and `-`
+0x0p+0
+0x0p-0
+0x0p+123
+0x0p-123
+
+# As integers
+0x123L
+0X123L
+0xDEADL
+0XDEADL
+0x0p0L
+0x0P0L
+0x0p+0L
+0x0p-0L
+
 # ------------------------------------------------------------------------------
 # scientific notation floats
 
