@@ -4,6 +4,12 @@
 foo::
 foo::bar
 foo::bar(1)
+foo::...
+foo::..1
+...::foo
+..1::foo
+...::...
+..1::..1
 
 # ------------------------------------------------------------------------------
 # namespace internal
@@ -11,6 +17,12 @@ foo::bar(1)
 foo:::
 foo:::bar
 foo:::bar(1)
+foo:::...
+foo:::..1
+...:::foo
+..1:::foo
+...:::...
+..1:::..1
 
 # ------------------------------------------------------------------------------
 # namespace missing rhs
